#!/bin/sh

### build my info/dep file(s) and copy into /tmp before running script

# build depends....cmake is preferred by upstream maintainer 
tce-load -i compiletc submitqc4 wget squashfs-tools-4.x cmake gettext
tce-load -i ncurses-dev ncursesw-dev glibc_apps perl_Curses  
tce-load -i python-dev ruby ruby-dev lua-dev tcl-dev guile-dev curl-dev 
tce-load -i libgcrypt-dev gnutls2-dev curl asciidoc libtasn1-dev aspell-dev


### asciidoc....has source-highlight-filter but not source-highlight
# I prefer wget to use no clobber as I retest the script

# download unpack weechat
cd /tmp
/usr/local/bin/wget -nc http://weechat.org/files/src/weechat-0.3.9.2.tar.gz
gunzip weechat-0.3.9.2.tar.gz
tar xvf weechat-0.3.9.2.tar

# download unpack plugins
# due to name may confuse with plugins from main tcz
# these will be called scripts eventually
/usr/local/bin/wget -nc http://weechat.org/files/src/weechat-plugins.tar.gz
gunzip weechat-plugins.tar.gz
tar xvf weechat-plugins.tar
 

# extension wiki to cheat off
export CFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export CXXFLAGS="-march=i486 -mtune=i686 -Os -pipe"
export LDFLAGS="-Wl,-O1"

# start weechat 
cd /tmp/weechat-0.3.9.2
./configure --prefix=/usr/local 
cmake .
make DESTDIR=/tmp/weechat install


############### dev
cd /tmp
mkdir -p weechat-dev/usr/local/lib
mv weechat/usr/local/include weechat-dev/usr/local
mv weechat/usr/local/lib/pkgconfig/ weechat-dev/usr/local/lib/
mksquashfs weechat-dev weechat-dev.tcz
md5sum weechat-dev.tcz > weechat-dev.tcz.md5.txt
cd weechat-dev
find usr -not -type d > weechat-dev.tcz.list
mv -f weechat-dev.tcz.list /tmp

############## doc 
cd /tmp
mkdir -p weechat-doc/usr/local/share/doc/weechat/de
mkdir -p weechat-doc/usr/local/share/doc/weechat/en
mkdir -p weechat-doc/usr/local/share/doc/weechat/es
mkdir -p weechat-doc/usr/local/share/doc/weechat/fr
mkdir -p weechat-doc/usr/local/share/doc/weechat/it
mkdir -p weechat-doc/usr/local/share/doc/weechat/ja
mkdir -p weechat-doc/usr/local/share/doc/weechat/pl
mkdir -p weechat-doc/usr/local/share/doc/weechat/ru

mv weechat/usr/local/share/man weechat-doc/usr/local/share

mv weechat-0.3.9.2/doc/de/*.txt weechat-doc/usr/local/share/doc/weechat/de
mv weechat-0.3.9.2/doc/en/*.txt weechat-doc/usr/local/share/doc/weechat/en
mv weechat-0.3.9.2/doc/es/*.txt weechat-doc/usr/local/share/doc/weechat/es
mv weechat-0.3.9.2/doc/fr/*.txt weechat-doc/usr/local/share/doc/weechat/fr
mv weechat-0.3.9.2/doc/it/*.txt weechat-doc/usr/local/share/doc/weechat/it
mv weechat-0.3.9.2/doc/ja/*.txt weechat-doc/usr/local/share/doc/weechat/ja
mv weechat-0.3.9.2/doc/pl/*.txt weechat-doc/usr/local/share/doc/weechat/pl
mv weechat-0.3.9.2/doc/ru/*.txt weechat-doc/usr/local/share/doc/weechat/ru

mksquashfs weechat-doc weechat-doc.tcz
md5sum weechat-doc.tcz > weechat-doc.tcz.md5.txt
cd weechat-doc
find usr -not -type d > weechat-doc.tcz.list
mv -f weechat-doc.tcz.list /tmp


################ locale
cd /tmp
mkdir -p weechat-locale/usr/local
mv weechat/usr/local/share weechat-locale/usr/local
mksquashfs weechat-locale weechat-locale.tcz
md5sum weechat-locale.tcz > weechat-locale.tcz.md5.txt
cd weechat-locale
find usr -not -type d > weechat-locale.tcz.list
mv -f weechat-locale.tcz.list /tmp

######### scripts 
cd /tmp
mkdir -p weechat-scripts/usr/local/lib/weechat/plugins
mv weechat-plugins/* weechat-scripts/usr/local/lib/weechat/plugins/

mksquashfs weechat-scripts weechat-scripts.tcz
md5sum weechat-scripts.tcz > weechat-scripts.tcz.md5.txt
cd weechat-scripts
find usr -not -type d > weechat-scripts.tcz.list
mv -f weechat-scripts.tcz.list /tmp

############## create desktop and icon
cd /tmp
# download an icon, my work a simple 48x48 
#--from webpage using mtpaint
/usr/local/bin/wget -nc http://ompldr.org/vZ3hybA/weechat.png
mkdir -p weechat/usr/local/share/pixmaps
mv weechat.png weechat/usr/local/share/pixmaps

mkdir -p weechat/usr/local/share/applications/

/bin/echo '[Desktop Entry]' >                                      weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Encoding=UTF-8' >>                                      weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Name=weechat' >>                                        weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Exec=weechat-curses' >>                                 weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Terminal=true' >>                                       weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Type=Application' >>                                    weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'Icon=weechat' >>                                        weechat/usr/local/share/applications/weechat.desktop
/bin/echo 'X-FullPathIcon=/usr/local/share/pixmaps/weechat.png' >> weechat/usr/local/share/applications/weechat.desktop


# weechat 
##########
cd /tmp
mksquashfs weechat weechat.tcz
md5sum weechat.tcz > weechat.tcz.md5.txt
cd weechat
find usr -not -type d > weechat.tcz.list
mv -f weechat.tcz.list /tmp


# finish off 
cd /tmp
submitqc4
